Struct fragile::SemiSticky
source · [−]pub struct SemiSticky<T> { /* private fields */ }Expand description
A SemiSticky<T> keeps a value T stored in a thread if it has a drop.
This is a combined version of Fragile<T> and Sticky<T>. If the type
does not have a drop it will effectively be a Fragile<T>, otherwise it
will be internally behave like a Sticky<T>.
Implementations
sourceimpl<T> SemiSticky<T>
impl<T> SemiSticky<T>
sourcepub fn new(value: T) -> Self
pub fn new(value: T) -> Self
Creates a new SemiSticky wrapping a value.
The value that is moved into the SemiSticky can be non Send and
will be anchored to the thread that created the object. If the
sticky wrapper type ends up being send from thread to thread
only the original thread can interact with the value. In case the
value does not have Drop it will be stored in the SemiSticky
instead.
sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Returns true if the access is valid.
This will be false if the value was sent to another thread.
sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the SemiSticky, returning the wrapped value.
Panics
Panics if called from a different thread than the one where the original value was created.
sourcepub fn try_into_inner(self) -> Result<T, Self>
pub fn try_into_inner(self) -> Result<T, Self>
Consumes the SemiSticky, returning the wrapped value if successful.
The wrapped value is returned if this is called from the same thread
as the one where the original value was created, otherwise the
SemiSticky is returned as Err(self).
sourcepub fn get_mut(&mut self) -> &mut T
pub fn get_mut(&mut self) -> &mut T
Mutably borrows the wrapped value.
Panics
Panics if the calling thread is not the one that wrapped the value.
For a non-panicking variant, use try_get_mut.
sourcepub fn try_get(&self) -> Result<&T, InvalidThreadAccess>
pub fn try_get(&self) -> Result<&T, InvalidThreadAccess>
Tries to immutably borrow the wrapped value.
Returns None if the calling thread is not the one that wrapped the value.
sourcepub fn try_get_mut(&mut self) -> Result<&mut T, InvalidThreadAccess>
pub fn try_get_mut(&mut self) -> Result<&mut T, InvalidThreadAccess>
Tries to mutably borrow the wrapped value.
Returns None if the calling thread is not the one that wrapped the value.